==> os_sys-1.7.2.tar.gz: os_sys-1.7.2/server/contrib/gis/db/backends/mysql/introspection.py <==
from MySQLdb.constants import FIELD_TYPE

from server.contrib.gis.gdal import OGRGeomType
from server.db.backends.mysql.introspection import DatabaseIntrospection


class MySQLIntrospection(DatabaseIntrospection):
    # Updating the data_types_reverse dictionary with the appropriate
    # type for Geometry fields.
    data_types_reverse = DatabaseIntrospection.data_types_reverse.copy()
    data_types_reverse[FIELD_TYPE.GEOMETRY] = 'GeometryField'

    def get_geometry_type(self, table_name, geo_col):
        with self.connection.cursor() as cursor:
            # In order to get the specific geometry type of the field,
            # we introspect on the table definition using `DESCRIBE`.
            cursor.execute('DESCRIBE %s' %
                           self.connection.ops.quote_name(table_name))
            # Increment over description info until we get to the geometry
            # column.
            for column, typ, null, key, default, extra in cursor.fetchall():
                if column == geo_col:
                    # Using OGRGeomType to convert from OGC name to Django field.
                    # MySQL does not support 3D or SRIDs, so the field params
                    # are empty.
                    field_type = OGRGeomType(typ).server
                    field_params = {}
                    break
        return field_type, field_params

    def supports_spatial_index(self, cursor, table_name):
        # Supported with MyISAM, or InnoDB on MySQL 5.7.5+
        storage_engine = self.get_storage_engine(cursor, table_name)
        return (
            (storage_engine == 'InnoDB' and self.connection.mysql_version >= (5, 7, 5)) or
            storage_engine == 'MyISAM'
        )

==> os_sys-2.0.3.tar.gz: os_sys-2.0.3/server/contrib/gis/db/backends/mysql/introspection.py <==
from MySQLdb.constants import FIELD_TYPE

from server.contrib.gis.gdal import OGRGeomType
from server.db.backends.mysql.introspection import DatabaseIntrospection


class MySQLIntrospection(DatabaseIntrospection):
    # Updating the data_types_reverse dictionary with the appropriate
    # type for Geometry fields.
    data_types_reverse = DatabaseIntrospection.data_types_reverse.copy()
    data_types_reverse[FIELD_TYPE.GEOMETRY] = 'GeometryField'

    def get_geometry_type(self, table_name, geo_col):
        with self.connection.cursor() as cursor:
            # In order to get the specific geometry type of the field,
            # we introspect on the table definition using `DESCRIBE`.
            cursor.execute('DESCRIBE %s' %
                           self.connection.ops.quote_name(table_name))
            # Increment over description info until we get to the geometry
            # column.
            for column, typ, null, key, default, extra in cursor.fetchall():
                if column == geo_col:
                    # Using OGRGeomType to convert from OGC name to Server field.
                    # MySQL does not support 3D or SRIDs, so the field params
                    # are empty.
                    field_type = OGRGeomType(typ).server
                    field_params = {}
                    break
        return field_type, field_params

    def supports_spatial_index(self, cursor, table_name):
        # Supported with MyISAM, or InnoDB on MySQL 5.7.5+
        storage_engine = self.get_storage_engine(cursor, table_name)
        return (
            (storage_engine == 'InnoDB' and self.connection.mysql_version >= (5, 7, 5)) or
            storage_engine == 'MyISAM'
        )
